searchData={"items":[{"type":"module","title":"BeamCampus.BitFlags","doc":"This module is used to manipulate bitwise flags.\n\n  Inspired by: [Flags in C#](https://stackoverflow.com/questions/8447/what-does-the-flags-enum-attribute-mean-in-c)\n\n  Event sourced systems often rely on flags to indicate the state of the aggregate at any given time.\n  In essence, an event sourced aggregate is a finite state machine and this state is \n  often represented as a set of flags, to be used as a shorthand for the state of the aggregate.\n\n  In this module, we define a set of functions that can be used to manipulate these flags.","ref":"BeamCampus.BitFlags.html"},{"type":"function","title":"BeamCampus.BitFlags.decompose/1","doc":"","ref":"BeamCampus.BitFlags.html#decompose/1"},{"type":"function","title":"BeamCampus.BitFlags.has?/2","doc":"Returs true if the given flag is set in the target state.\n  In other words, it returns true if the bit that corresponds to the flag is set.\n  GIVEN: original_state is `0b01100100` (integer: 100)\n  WHEN the flag to be checked is `0b01000000` (integer: 64)\n  THEN the result is `true`\n\n  Example:\n  iex> BitFlags.has?(100, 64)\n  true","ref":"BeamCampus.BitFlags.html#has?/2"},{"type":"function","title":"BeamCampus.BitFlags.has_all?/2","doc":"Returns true if ALL the flags are set in the target state.\n  In other words, it returns true if ALL the bits that correspond to the flags are set.\n  GIVEN: original_state is `0b01100100` (integer: 100)\n  WHEN the flags to be checked are `[0b01000000, 0b10000000]` (integers: 64, 128)\n  THEN the result is `true`\n  AND WHEN the flags to be checked are `[0b01000000, 0b00000100]` (integers: 64, 8)\n  THEN the result is `false`\n\n  Example:\n  iex> BitFlags.has_all?(100, [64, 128])\n  true\n  iex> BitFlags.has_all?(100, [64, 8])\n  false","ref":"BeamCampus.BitFlags.html#has_all?/2"},{"type":"function","title":"BeamCampus.BitFlags.has_any?/2","doc":"Returns true if any of the flags are set in the target state.\n  In other words, it returns true if any of the bits that correspond to the flags are set.\n  GIVEN: original_state is `0b01100100` (integer: 100)\n  WHEN the flags to be checked are `[0b01000000, 0b10000000]` (integers: 64, 128)\n  THEN the result is `true`\n\n  Example:\n  iex> BitFlags.has_any?(100, [64, 128])\n  true","ref":"BeamCampus.BitFlags.html#has_any?/2"},{"type":"function","title":"BeamCampus.BitFlags.has_not?/2","doc":"Returns true if the given flag is NOT set in the target state.\n  In other words, it returns true if the bit that corresponds to the flag is NOT set.\n  GIVEN: original_state is `0b01100100` (integer: 100)\n  WHEN the flag to be checked is `0b01000000` (integer: 64)\n  THEN the result is `false`\n  AND WHEN the flag to be checked is `0b00000100` (integer: 8)\n  THEN the result is `true`\n\n  Example:\n  iex> BitFlags.has_not?(100, 64)\n  false\n  iex> BitFlags.has_not?(100, 8)\n  true","ref":"BeamCampus.BitFlags.html#has_not?/2"},{"type":"function","title":"BeamCampus.BitFlags.highest/2","doc":"Returns the highest flag in the target state.\n  GIVEN: target_state is `0b01100100` (integer: 100)    \n  AND the flag_map is:\n      %{\n         0 => \"None\",\n         1 => \"Ready\",\n         2 => \"In Progress\",\n         4 => \"Completed\",\n         8 => \"Cancelled\",\n         16 => \"Failed\",\n         32 => \"Archived\",\n         64 => \"Ready to Archive\",\n         128 => \"Ready to Publish\",\n      }\n  THEN the result is `Ready to Archive`\n\n  Example:\n  iex> descriptions = \n  ...>  %{\n  ...>       0 => \"None\",\n  ...>       1 => \"Ready\",\n  ...>       2 => \"In Progress\",\n  ...>       4 => \"Completed\",\n  ...>       8 => \"Cancelled\",\n  ...>       16 => \"Failed\",\n  ...>       32 => \"Archived\",\n  ...>       64 => \"Ready to Archive\",\n  ...>       128 => \"Ready to Publish\",\n  ...>  }\n  %{\n     0 => \"None\",\n     1 => \"Ready\",\n     2 => \"In Progress\",\n     4 => \"Completed\",\n     8 => \"Cancelled\",\n     16 => \"Failed\",\n     32 => \"Archived\",\n     64 => \"Ready to Archive\",\n     128 => \"Ready to Publish\",\n  }\n  iex> BitFlags.highest(100, descriptions)\n  \"Ready to Archive\"","ref":"BeamCampus.BitFlags.html#highest/2"},{"type":"function","title":"BeamCampus.BitFlags.lowest/2","doc":"Returns the lowest flag in the bit flag map.\n  GIVEN: target_state is `0b01100100` (integer: 100)\n  AND the flag_map is:\n      %{\n         0 => \"None\",\n         1 => \"Ready\",\n         2 => \"In Progress\",\n         4 => \"Completed\",\n         8 => \"Cancelled\",\n         16 => \"Failed\",\n         32 => \"Archived\",\n         64 => \"Ready to Archive\",\n         128 => \"Ready to Publish\",\n      }\n   THEN the result is `Ready`\n\n  Example:\n  iex> descriptions = \n  ...>  %{\n  ...>       0 => \"None\",\n  ...>       1 => \"Ready\",\n  ...>       2 => \"In Progress\",\n  ...>       4 => \"Completed\",\n  ...>       8 => \"Cancelled\",\n  ...>       16 => \"Failed\",\n  ...>       32 => \"Archived\",\n  ...>       64 => \"Ready to Archive\",\n  ...>       128 => \"Ready to Publish\",\n  ...>  }\n  %{\n     0 => \"None\",\n     1 => \"Ready\",\n     2 => \"In Progress\",\n     4 => \"Completed\",\n     8 => \"Cancelled\",\n     16 => \"Failed\",\n     32 => \"Archived\",\n     64 => \"Ready to Archive\",\n     128 => \"Ready to Publish\",\n  }\n  iex> BitFlags.lowest(100, descriptions)\n  \"Ready\"","ref":"BeamCampus.BitFlags.html#lowest/2"},{"type":"function","title":"BeamCampus.BitFlags.set/2","doc":"","ref":"BeamCampus.BitFlags.html#set/2"},{"type":"function","title":"Description - BeamCampus.BitFlags.set/2","doc":"Returns the bitwise OR of two flags.\n  In other words, it sets the bit that corresopnds to the flag\n\n  - GIVEN: original_state is `0b00100100` (integer: 36) \n  - WHEN the flag to be set is `0b01000000` (integer: 64)\n  - THEN the result is `0b01100100` (integer: 100)","ref":"BeamCampus.BitFlags.html#set/2-description"},{"type":"function","title":"Parameters - BeamCampus.BitFlags.set/2","doc":"- target: the integer to be set\n  - flag: the integer to be set","ref":"BeamCampus.BitFlags.html#set/2-parameters"},{"type":"function","title":"Output - BeamCampus.BitFlags.set/2","doc":"The integer representation of the state after setting the flag","ref":"BeamCampus.BitFlags.html#set/2-output"},{"type":"function","title":"Examples - BeamCampus.BitFlags.set/2","doc":"iex> BitFlags.set(36, 64)\n  100","ref":"BeamCampus.BitFlags.html#set/2-examples"},{"type":"function","title":"BeamCampus.BitFlags.set_all/2","doc":"Returns the bitwise OR of multiple flags against a given state.\n  In other words, it sets the bits that corresopnds to the flags\n  GIVEN: original_state is `0b00100100` (integer: 36)\n  WHEN the flags to be set are `[0b01000000, 0b10000000]` (integers: 64, 128)\n  THEN the result is `0b11100100` (integer: 228)\n\n  Example:\n  iex> BitFlags.set_all(36, [64, 128])\n  228","ref":"BeamCampus.BitFlags.html#set_all/2"},{"type":"function","title":"BeamCampus.BitFlags.to_list/2","doc":"Returns a list of flag descriptions that are set in the target state.\n  GIVEN: original_state is `0b01100100` (integer: 100)\n  AND the flag_map is:\n     %{\n        0 => \"None\",\n        1 => \"Ready\",\n        2 => \"In Progress\",\n        4 => \"Completed\",\n        8 => \"Cancelled\",\n        16 => \"Failed\",\n        32 => \"Archived\",\n        64 => \"Ready to Archive\",\n        128 => \"Ready to Publish\",\n        256 => \"Published\",\n        512 => \"Unpublished\",\n     }\n  WHEN the target state is `0b01100100` (integer: 100)\n  THEN the result is `[\"Completed\", \"Archived\", \"Ready to Archive\"]`\n\n  Example: \n  iex> descriptions = \n  ...>  %{\n  ...>       0 => \"None\",\n  ...>       1 => \"Ready\",\n  ...>       2 => \"In Progress\",\n  ...>       4 => \"Completed\",\n  ...>       8 => \"Cancelled\",\n  ...>       16 => \"Failed\",\n  ...>       32 => \"Archived\",\n  ...>       64 => \"Ready to Archive\",\n  ...>       128 => \"Ready to Publish\",\n  ...>       256 => \"Published\",\n  ...>       512 => \"Unpublished\",\n  ...>  }\n  iex> BitFlags.to_list(100, descriptions)\n  [\"Completed\", \"Archived\", \"Ready to Archive\"]","ref":"BeamCampus.BitFlags.html#to_list/2"},{"type":"function","title":"BeamCampus.BitFlags.to_string/2","doc":"Returns a string representation of the bit flags.\n  GIVEN: target_state is `0b01100100` (integer: 100)\n  AND the flag_map is:\n       %{\n         0 => \"None\",\n         1 => \"Ready\",\n         2 => \"In Progress\",\n         4 => \"Completed\",\n         8 => \"Cancelled\",\n         16 => \"Failed\",\n         32 => \"Archived\",\n         64 => \"Ready to Archive\",\n         128 => \"Ready to Publish\",\n      }\n  THEN the result is `\"Completed, Archived, Ready to Archive\"`\n\n  Example:\n  iex> descriptions =\n  ...>  %{\n  ...>       0 => \"None\",\n  ...>       1 => \"Ready\",\n  ...>       2 => \"In Progress\",\n  ...>       4 => \"Completed\",\n  ...>       8 => \"Cancelled\",\n  ...>       16 => \"Failed\",\n  ...>       32 => \"Archived\",\n  ...>       64 => \"Ready to Archive\",\n  ...>       128 => \"Ready to Publish\",\n  ...>  }\n  iex> BitFlags.to_string(100, descriptions)\n  \"Completed, Archived, Ready to Archive\"","ref":"BeamCampus.BitFlags.html#to_string/2"},{"type":"function","title":"BeamCampus.BitFlags.unset/2","doc":"","ref":"BeamCampus.BitFlags.html#unset/2"},{"type":"function","title":"Description - BeamCampus.BitFlags.unset/2","doc":"Returns the bitwise AND of two flags.\n  In other words, it unsets the bit that corresopnds to the flag\n\n  - GIVEN: original_state is `0b01100100` (integer: 100)\n  - WHEN the flag to be unset is `0b01000000` (integer: 64)\n  - THEN the result is `0b00100100` (integer: 36)","ref":"BeamCampus.BitFlags.html#unset/2-description"},{"type":"function","title":"Parameters - BeamCampus.BitFlags.unset/2","doc":"- `target`: the integer representation of the state\n    - `flag`  : the integer representation of the flag","ref":"BeamCampus.BitFlags.html#unset/2-parameters"},{"type":"function","title":"Output - BeamCampus.BitFlags.unset/2","doc":"The integer representation of the state after unsetting the flag","ref":"BeamCampus.BitFlags.html#unset/2-output"},{"type":"function","title":"Examples - BeamCampus.BitFlags.unset/2","doc":"iex> BitFlags.unset(100, 64)\n    36","ref":"BeamCampus.BitFlags.html#unset/2-examples"},{"type":"function","title":"BeamCampus.BitFlags.unset_all/2","doc":"Returns the bitwise AND of multiple flags against a given state.\n  In other words, it unsets the bits that corresopnds to the flags\n  GIVEN: original_state is `0b11100100` (integer: 228)\n  WHEN the flags to be unset are `[0b01000000, 0b10000000]` (integers: 64, 128)\n  THEN the result is `0b00100100` (integer: 36)\n\n  Example:\n  iex> BitFlags.unset_all(228, [64, 128])\n  36","ref":"BeamCampus.BitFlags.html#unset_all/2"},{"type":"module","title":"BeamCampus.ColorFuncs","doc":"This module is used to manipulate colors.\n  It offers a set of functions that can be used to \n  change the color of text in the terminal, using ANSI escape codes.\n  It covers all color combinations and effects supported by ANSI.","ref":"BeamCampus.ColorFuncs.html"},{"type":"function","title":"BeamCampus.ColorFuncs.black_on_black/0","doc":"","ref":"BeamCampus.ColorFuncs.html#black_on_black/0"},{"type":"function","title":"BeamCampus.ColorFuncs.black_on_blue/0","doc":"","ref":"BeamCampus.ColorFuncs.html#black_on_blue/0"},{"type":"function","title":"BeamCampus.ColorFuncs.black_on_bright_black/0","doc":"","ref":"BeamCampus.ColorFuncs.html#black_on_bright_black/0"},{"type":"function","title":"BeamCampus.ColorFuncs.black_on_bright_blue/0","doc":"","ref":"BeamCampus.ColorFuncs.html#black_on_bright_blue/0"},{"type":"function","title":"BeamCampus.ColorFuncs.black_on_bright_cyan/0","doc":"","ref":"BeamCampus.ColorFuncs.html#black_on_bright_cyan/0"},{"type":"function","title":"BeamCampus.ColorFuncs.black_on_bright_green/0","doc":"","ref":"BeamCampus.ColorFuncs.html#black_on_bright_green/0"},{"type":"function","title":"BeamCampus.ColorFuncs.black_on_bright_magenta/0","doc":"","ref":"BeamCampus.ColorFuncs.html#black_on_bright_magenta/0"},{"type":"function","title":"BeamCampus.ColorFuncs.black_on_bright_red/0","doc":"","ref":"BeamCampus.ColorFuncs.html#black_on_bright_red/0"},{"type":"function","title":"BeamCampus.ColorFuncs.black_on_bright_white/0","doc":"","ref":"BeamCampus.ColorFuncs.html#black_on_bright_white/0"},{"type":"function","title":"BeamCampus.ColorFuncs.black_on_bright_yellow/0","doc":"","ref":"BeamCampus.ColorFuncs.html#black_on_bright_yellow/0"},{"type":"function","title":"BeamCampus.ColorFuncs.black_on_cyan/0","doc":"","ref":"BeamCampus.ColorFuncs.html#black_on_cyan/0"},{"type":"function","title":"BeamCampus.ColorFuncs.black_on_green/0","doc":"","ref":"BeamCampus.ColorFuncs.html#black_on_green/0"},{"type":"function","title":"BeamCampus.ColorFuncs.black_on_magenta/0","doc":"","ref":"BeamCampus.ColorFuncs.html#black_on_magenta/0"},{"type":"function","title":"BeamCampus.ColorFuncs.black_on_red/0","doc":"","ref":"BeamCampus.ColorFuncs.html#black_on_red/0"},{"type":"function","title":"BeamCampus.ColorFuncs.black_on_white/0","doc":"","ref":"BeamCampus.ColorFuncs.html#black_on_white/0"},{"type":"function","title":"BeamCampus.ColorFuncs.black_on_yellow/0","doc":"","ref":"BeamCampus.ColorFuncs.html#black_on_yellow/0"},{"type":"function","title":"BeamCampus.ColorFuncs.blue_on_black/0","doc":"","ref":"BeamCampus.ColorFuncs.html#blue_on_black/0"},{"type":"function","title":"BeamCampus.ColorFuncs.blue_on_blue/0","doc":"","ref":"BeamCampus.ColorFuncs.html#blue_on_blue/0"},{"type":"function","title":"BeamCampus.ColorFuncs.blue_on_bright_black/0","doc":"","ref":"BeamCampus.ColorFuncs.html#blue_on_bright_black/0"},{"type":"function","title":"BeamCampus.ColorFuncs.blue_on_bright_blue/0","doc":"","ref":"BeamCampus.ColorFuncs.html#blue_on_bright_blue/0"},{"type":"function","title":"BeamCampus.ColorFuncs.blue_on_bright_cyan/0","doc":"","ref":"BeamCampus.ColorFuncs.html#blue_on_bright_cyan/0"},{"type":"function","title":"BeamCampus.ColorFuncs.blue_on_bright_green/0","doc":"","ref":"BeamCampus.ColorFuncs.html#blue_on_bright_green/0"},{"type":"function","title":"BeamCampus.ColorFuncs.blue_on_bright_magenta/0","doc":"","ref":"BeamCampus.ColorFuncs.html#blue_on_bright_magenta/0"},{"type":"function","title":"BeamCampus.ColorFuncs.blue_on_bright_red/0","doc":"","ref":"BeamCampus.ColorFuncs.html#blue_on_bright_red/0"},{"type":"function","title":"BeamCampus.ColorFuncs.blue_on_bright_white/0","doc":"","ref":"BeamCampus.ColorFuncs.html#blue_on_bright_white/0"},{"type":"function","title":"BeamCampus.ColorFuncs.blue_on_bright_yellow/0","doc":"","ref":"BeamCampus.ColorFuncs.html#blue_on_bright_yellow/0"},{"type":"function","title":"BeamCampus.ColorFuncs.blue_on_cyan/0","doc":"","ref":"BeamCampus.ColorFuncs.html#blue_on_cyan/0"},{"type":"function","title":"BeamCampus.ColorFuncs.blue_on_green/0","doc":"","ref":"BeamCampus.ColorFuncs.html#blue_on_green/0"},{"type":"function","title":"BeamCampus.ColorFuncs.blue_on_magenta/0","doc":"","ref":"BeamCampus.ColorFuncs.html#blue_on_magenta/0"},{"type":"function","title":"BeamCampus.ColorFuncs.blue_on_red/0","doc":"","ref":"BeamCampus.ColorFuncs.html#blue_on_red/0"},{"type":"function","title":"BeamCampus.ColorFuncs.blue_on_white/0","doc":"","ref":"BeamCampus.ColorFuncs.html#blue_on_white/0"},{"type":"function","title":"BeamCampus.ColorFuncs.blue_on_yellow/0","doc":"","ref":"BeamCampus.ColorFuncs.html#blue_on_yellow/0"},{"type":"function","title":"BeamCampus.ColorFuncs.bright_black_on_black/0","doc":"","ref":"BeamCampus.ColorFuncs.html#bright_black_on_black/0"},{"type":"function","title":"BeamCampus.ColorFuncs.bright_black_on_blue/0","doc":"","ref":"BeamCampus.ColorFuncs.html#bright_black_on_blue/0"},{"type":"function","title":"BeamCampus.ColorFuncs.bright_black_on_bright_black/0","doc":"","ref":"BeamCampus.ColorFuncs.html#bright_black_on_bright_black/0"},{"type":"function","title":"BeamCampus.ColorFuncs.bright_black_on_bright_blue/0","doc":"","ref":"BeamCampus.ColorFuncs.html#bright_black_on_bright_blue/0"},{"type":"function","title":"BeamCampus.ColorFuncs.bright_black_on_bright_cyan/0","doc":"","ref":"BeamCampus.ColorFuncs.html#bright_black_on_bright_cyan/0"},{"type":"function","title":"BeamCampus.ColorFuncs.bright_black_on_bright_green/0","doc":"","ref":"BeamCampus.ColorFuncs.html#bright_black_on_bright_green/0"},{"type":"function","title":"BeamCampus.ColorFuncs.bright_black_on_bright_magenta/0","doc":"","ref":"BeamCampus.ColorFuncs.html#bright_black_on_bright_magenta/0"},{"type":"function","title":"BeamCampus.ColorFuncs.bright_black_on_bright_red/0","doc":"","ref":"BeamCampus.ColorFuncs.html#bright_black_on_bright_red/0"},{"type":"function","title":"BeamCampus.ColorFuncs.bright_black_on_bright_white/0","doc":"","ref":"BeamCampus.ColorFuncs.html#bright_black_on_bright_white/0"},{"type":"function","title":"BeamCampus.ColorFuncs.bright_black_on_bright_yellow/0","doc":"","ref":"BeamCampus.ColorFuncs.html#bright_black_on_bright_yellow/0"},{"type":"function","title":"BeamCampus.ColorFuncs.bright_black_on_cyan/0","doc":"","ref":"BeamCampus.ColorFuncs.html#bright_black_on_cyan/0"},{"type":"function","title":"BeamCampus.ColorFuncs.bright_black_on_green/0","doc":"","ref":"BeamCampus.ColorFuncs.html#bright_black_on_green/0"},{"type":"function","title":"BeamCampus.ColorFuncs.bright_black_on_magenta/0","doc":"","ref":"BeamCampus.ColorFuncs.html#bright_black_on_magenta/0"},{"type":"function","title":"BeamCampus.ColorFuncs.bright_black_on_red/0","doc":"","ref":"BeamCampus.ColorFuncs.html#bright_black_on_red/0"},{"type":"function","title":"BeamCampus.ColorFuncs.bright_black_on_white/0","doc":"","ref":"BeamCampus.ColorFuncs.html#bright_black_on_white/0"},{"type":"function","title":"BeamCampus.ColorFuncs.bright_black_on_yellow/0","doc":"","ref":"BeamCampus.ColorFuncs.html#bright_black_on_yellow/0"},{"type":"function","title":"BeamCampus.ColorFuncs.bright_blue_on_black/0","doc":"","ref":"BeamCampus.ColorFuncs.html#bright_blue_on_black/0"},{"type":"function","title":"BeamCampus.ColorFuncs.bright_blue_on_blue/0","doc":"","ref":"BeamCampus.ColorFuncs.html#bright_blue_on_blue/0"},{"type":"function","title":"BeamCampus.ColorFuncs.bright_blue_on_bright_black/0","doc":"","ref":"BeamCampus.ColorFuncs.html#bright_blue_on_bright_black/0"},{"type":"function","title":"BeamCampus.ColorFuncs.bright_blue_on_bright_blue/0","doc":"","ref":"BeamCampus.ColorFuncs.html#bright_blue_on_bright_blue/0"},{"type":"function","title":"BeamCampus.ColorFuncs.bright_blue_on_bright_cyan/0","doc":"","ref":"BeamCampus.ColorFuncs.html#bright_blue_on_bright_cyan/0"},{"type":"function","title":"BeamCampus.ColorFuncs.bright_blue_on_bright_green/0","doc":"","ref":"BeamCampus.ColorFuncs.html#bright_blue_on_bright_green/0"},{"type":"function","title":"BeamCampus.ColorFuncs.bright_blue_on_bright_magenta/0","doc":"","ref":"BeamCampus.ColorFuncs.html#bright_blue_on_bright_magenta/0"},{"type":"function","title":"BeamCampus.ColorFuncs.bright_blue_on_bright_red/0","doc":"","ref":"BeamCampus.ColorFuncs.html#bright_blue_on_bright_red/0"},{"type":"function","title":"BeamCampus.ColorFuncs.bright_blue_on_bright_white/0","doc":"","ref":"BeamCampus.ColorFuncs.html#bright_blue_on_bright_white/0"},{"type":"function","title":"BeamCampus.ColorFuncs.bright_blue_on_bright_yellow/0","doc":"","ref":"BeamCampus.ColorFuncs.html#bright_blue_on_bright_yellow/0"},{"type":"function","title":"BeamCampus.ColorFuncs.bright_blue_on_cyan/0","doc":"","ref":"BeamCampus.ColorFuncs.html#bright_blue_on_cyan/0"},{"type":"function","title":"BeamCampus.ColorFuncs.bright_blue_on_green/0","doc":"","ref":"BeamCampus.ColorFuncs.html#bright_blue_on_green/0"},{"type":"function","title":"BeamCampus.ColorFuncs.bright_blue_on_magenta/0","doc":"","ref":"BeamCampus.ColorFuncs.html#bright_blue_on_magenta/0"},{"type":"function","title":"BeamCampus.ColorFuncs.bright_blue_on_red/0","doc":"","ref":"BeamCampus.ColorFuncs.html#bright_blue_on_red/0"},{"type":"function","title":"BeamCampus.ColorFuncs.bright_blue_on_white/0","doc":"","ref":"BeamCampus.ColorFuncs.html#bright_blue_on_white/0"},{"type":"function","title":"BeamCampus.ColorFuncs.bright_blue_on_yellow/0","doc":"","ref":"BeamCampus.ColorFuncs.html#bright_blue_on_yellow/0"},{"type":"function","title":"BeamCampus.ColorFuncs.bright_cyan_on_black/0","doc":"","ref":"BeamCampus.ColorFuncs.html#bright_cyan_on_black/0"},{"type":"function","title":"BeamCampus.ColorFuncs.bright_cyan_on_blue/0","doc":"","ref":"BeamCampus.ColorFuncs.html#bright_cyan_on_blue/0"},{"type":"function","title":"BeamCampus.ColorFuncs.bright_cyan_on_bright_black/0","doc":"","ref":"BeamCampus.ColorFuncs.html#bright_cyan_on_bright_black/0"},{"type":"function","title":"BeamCampus.ColorFuncs.bright_cyan_on_bright_blue/0","doc":"","ref":"BeamCampus.ColorFuncs.html#bright_cyan_on_bright_blue/0"},{"type":"function","title":"BeamCampus.ColorFuncs.bright_cyan_on_bright_cyan/0","doc":"","ref":"BeamCampus.ColorFuncs.html#bright_cyan_on_bright_cyan/0"},{"type":"function","title":"BeamCampus.ColorFuncs.bright_cyan_on_bright_green/0","doc":"","ref":"BeamCampus.ColorFuncs.html#bright_cyan_on_bright_green/0"},{"type":"function","title":"BeamCampus.ColorFuncs.bright_cyan_on_bright_magenta/0","doc":"","ref":"BeamCampus.ColorFuncs.html#bright_cyan_on_bright_magenta/0"},{"type":"function","title":"BeamCampus.ColorFuncs.bright_cyan_on_bright_red/0","doc":"","ref":"BeamCampus.ColorFuncs.html#bright_cyan_on_bright_red/0"},{"type":"function","title":"BeamCampus.ColorFuncs.bright_cyan_on_bright_white/0","doc":"","ref":"BeamCampus.ColorFuncs.html#bright_cyan_on_bright_white/0"},{"type":"function","title":"BeamCampus.ColorFuncs.bright_cyan_on_bright_yellow/0","doc":"","ref":"BeamCampus.ColorFuncs.html#bright_cyan_on_bright_yellow/0"},{"type":"function","title":"BeamCampus.ColorFuncs.bright_cyan_on_cyan/0","doc":"","ref":"BeamCampus.ColorFuncs.html#bright_cyan_on_cyan/0"},{"type":"function","title":"BeamCampus.ColorFuncs.bright_cyan_on_green/0","doc":"","ref":"BeamCampus.ColorFuncs.html#bright_cyan_on_green/0"},{"type":"function","title":"BeamCampus.ColorFuncs.bright_cyan_on_magenta/0","doc":"","ref":"BeamCampus.ColorFuncs.html#bright_cyan_on_magenta/0"},{"type":"function","title":"BeamCampus.ColorFuncs.bright_cyan_on_red/0","doc":"","ref":"BeamCampus.ColorFuncs.html#bright_cyan_on_red/0"},{"type":"function","title":"BeamCampus.ColorFuncs.bright_cyan_on_white/0","doc":"","ref":"BeamCampus.ColorFuncs.html#bright_cyan_on_white/0"},{"type":"function","title":"BeamCampus.ColorFuncs.bright_cyan_on_yellow/0","doc":"","ref":"BeamCampus.ColorFuncs.html#bright_cyan_on_yellow/0"},{"type":"function","title":"BeamCampus.ColorFuncs.bright_green_on_black/0","doc":"","ref":"BeamCampus.ColorFuncs.html#bright_green_on_black/0"},{"type":"function","title":"BeamCampus.ColorFuncs.bright_green_on_blue/0","doc":"","ref":"BeamCampus.ColorFuncs.html#bright_green_on_blue/0"},{"type":"function","title":"BeamCampus.ColorFuncs.bright_green_on_bright_black/0","doc":"","ref":"BeamCampus.ColorFuncs.html#bright_green_on_bright_black/0"},{"type":"function","title":"BeamCampus.ColorFuncs.bright_green_on_bright_blue/0","doc":"","ref":"BeamCampus.ColorFuncs.html#bright_green_on_bright_blue/0"},{"type":"function","title":"BeamCampus.ColorFuncs.bright_green_on_bright_cyan/0","doc":"","ref":"BeamCampus.ColorFuncs.html#bright_green_on_bright_cyan/0"},{"type":"function","title":"BeamCampus.ColorFuncs.bright_green_on_bright_green/0","doc":"","ref":"BeamCampus.ColorFuncs.html#bright_green_on_bright_green/0"},{"type":"function","title":"BeamCampus.ColorFuncs.bright_green_on_bright_magenta/0","doc":"","ref":"BeamCampus.ColorFuncs.html#bright_green_on_bright_magenta/0"},{"type":"function","title":"BeamCampus.ColorFuncs.bright_green_on_bright_red/0","doc":"","ref":"BeamCampus.ColorFuncs.html#bright_green_on_bright_red/0"},{"type":"function","title":"BeamCampus.ColorFuncs.bright_green_on_bright_white/0","doc":"","ref":"BeamCampus.ColorFuncs.html#bright_green_on_bright_white/0"},{"type":"function","title":"BeamCampus.ColorFuncs.bright_green_on_bright_yellow/0","doc":"","ref":"BeamCampus.ColorFuncs.html#bright_green_on_bright_yellow/0"},{"type":"function","title":"BeamCampus.ColorFuncs.bright_green_on_cyan/0","doc":"","ref":"BeamCampus.ColorFuncs.html#bright_green_on_cyan/0"},{"type":"function","title":"BeamCampus.ColorFuncs.bright_green_on_green/0","doc":"","ref":"BeamCampus.ColorFuncs.html#bright_green_on_green/0"},{"type":"function","title":"BeamCampus.ColorFuncs.bright_green_on_magenta/0","doc":"","ref":"BeamCampus.ColorFuncs.html#bright_green_on_magenta/0"},{"type":"function","title":"BeamCampus.ColorFuncs.bright_green_on_red/0","doc":"","ref":"BeamCampus.ColorFuncs.html#bright_green_on_red/0"},{"type":"function","title":"BeamCampus.ColorFuncs.bright_green_on_white/0","doc":"","ref":"BeamCampus.ColorFuncs.html#bright_green_on_white/0"},{"type":"function","title":"BeamCampus.ColorFuncs.bright_green_on_yellow/0","doc":"","ref":"BeamCampus.ColorFuncs.html#bright_green_on_yellow/0"},{"type":"function","title":"BeamCampus.ColorFuncs.bright_magenta_on_black/0","doc":"","ref":"BeamCampus.ColorFuncs.html#bright_magenta_on_black/0"},{"type":"function","title":"BeamCampus.ColorFuncs.bright_magenta_on_blue/0","doc":"","ref":"BeamCampus.ColorFuncs.html#bright_magenta_on_blue/0"},{"type":"function","title":"BeamCampus.ColorFuncs.bright_magenta_on_bright_black/0","doc":"","ref":"BeamCampus.ColorFuncs.html#bright_magenta_on_bright_black/0"},{"type":"function","title":"BeamCampus.ColorFuncs.bright_magenta_on_bright_blue/0","doc":"","ref":"BeamCampus.ColorFuncs.html#bright_magenta_on_bright_blue/0"},{"type":"function","title":"BeamCampus.ColorFuncs.bright_magenta_on_bright_cyan/0","doc":"","ref":"BeamCampus.ColorFuncs.html#bright_magenta_on_bright_cyan/0"},{"type":"function","title":"BeamCampus.ColorFuncs.bright_magenta_on_bright_green/0","doc":"","ref":"BeamCampus.ColorFuncs.html#bright_magenta_on_bright_green/0"},{"type":"function","title":"BeamCampus.ColorFuncs.bright_magenta_on_bright_magenta/0","doc":"","ref":"BeamCampus.ColorFuncs.html#bright_magenta_on_bright_magenta/0"},{"type":"function","title":"BeamCampus.ColorFuncs.bright_magenta_on_bright_red/0","doc":"","ref":"BeamCampus.ColorFuncs.html#bright_magenta_on_bright_red/0"},{"type":"function","title":"BeamCampus.ColorFuncs.bright_magenta_on_bright_white/0","doc":"","ref":"BeamCampus.ColorFuncs.html#bright_magenta_on_bright_white/0"},{"type":"function","title":"BeamCampus.ColorFuncs.bright_magenta_on_bright_yellow/0","doc":"","ref":"BeamCampus.ColorFuncs.html#bright_magenta_on_bright_yellow/0"},{"type":"function","title":"BeamCampus.ColorFuncs.bright_magenta_on_cyan/0","doc":"","ref":"BeamCampus.ColorFuncs.html#bright_magenta_on_cyan/0"},{"type":"function","title":"BeamCampus.ColorFuncs.bright_magenta_on_green/0","doc":"","ref":"BeamCampus.ColorFuncs.html#bright_magenta_on_green/0"},{"type":"function","title":"BeamCampus.ColorFuncs.bright_magenta_on_magenta/0","doc":"","ref":"BeamCampus.ColorFuncs.html#bright_magenta_on_magenta/0"},{"type":"function","title":"BeamCampus.ColorFuncs.bright_magenta_on_red/0","doc":"","ref":"BeamCampus.ColorFuncs.html#bright_magenta_on_red/0"},{"type":"function","title":"BeamCampus.ColorFuncs.bright_magenta_on_white/0","doc":"","ref":"BeamCampus.ColorFuncs.html#bright_magenta_on_white/0"},{"type":"function","title":"BeamCampus.ColorFuncs.bright_magenta_on_yellow/0","doc":"","ref":"BeamCampus.ColorFuncs.html#bright_magenta_on_yellow/0"},{"type":"function","title":"BeamCampus.ColorFuncs.bright_red_on_black/0","doc":"","ref":"BeamCampus.ColorFuncs.html#bright_red_on_black/0"},{"type":"function","title":"BeamCampus.ColorFuncs.bright_red_on_blue/0","doc":"","ref":"BeamCampus.ColorFuncs.html#bright_red_on_blue/0"},{"type":"function","title":"BeamCampus.ColorFuncs.bright_red_on_bright_black/0","doc":"","ref":"BeamCampus.ColorFuncs.html#bright_red_on_bright_black/0"},{"type":"function","title":"BeamCampus.ColorFuncs.bright_red_on_bright_blue/0","doc":"","ref":"BeamCampus.ColorFuncs.html#bright_red_on_bright_blue/0"},{"type":"function","title":"BeamCampus.ColorFuncs.bright_red_on_bright_cyan/0","doc":"","ref":"BeamCampus.ColorFuncs.html#bright_red_on_bright_cyan/0"},{"type":"function","title":"BeamCampus.ColorFuncs.bright_red_on_bright_green/0","doc":"","ref":"BeamCampus.ColorFuncs.html#bright_red_on_bright_green/0"},{"type":"function","title":"BeamCampus.ColorFuncs.bright_red_on_bright_magenta/0","doc":"","ref":"BeamCampus.ColorFuncs.html#bright_red_on_bright_magenta/0"},{"type":"function","title":"BeamCampus.ColorFuncs.bright_red_on_bright_red/0","doc":"","ref":"BeamCampus.ColorFuncs.html#bright_red_on_bright_red/0"},{"type":"function","title":"BeamCampus.ColorFuncs.bright_red_on_bright_white/0","doc":"","ref":"BeamCampus.ColorFuncs.html#bright_red_on_bright_white/0"},{"type":"function","title":"BeamCampus.ColorFuncs.bright_red_on_bright_yellow/0","doc":"","ref":"BeamCampus.ColorFuncs.html#bright_red_on_bright_yellow/0"},{"type":"function","title":"BeamCampus.ColorFuncs.bright_red_on_cyan/0","doc":"","ref":"BeamCampus.ColorFuncs.html#bright_red_on_cyan/0"},{"type":"function","title":"BeamCampus.ColorFuncs.bright_red_on_green/0","doc":"","ref":"BeamCampus.ColorFuncs.html#bright_red_on_green/0"},{"type":"function","title":"BeamCampus.ColorFuncs.bright_red_on_magenta/0","doc":"","ref":"BeamCampus.ColorFuncs.html#bright_red_on_magenta/0"},{"type":"function","title":"BeamCampus.ColorFuncs.bright_red_on_red/0","doc":"","ref":"BeamCampus.ColorFuncs.html#bright_red_on_red/0"},{"type":"function","title":"BeamCampus.ColorFuncs.bright_red_on_white/0","doc":"","ref":"BeamCampus.ColorFuncs.html#bright_red_on_white/0"},{"type":"function","title":"BeamCampus.ColorFuncs.bright_red_on_yellow/0","doc":"","ref":"BeamCampus.ColorFuncs.html#bright_red_on_yellow/0"},{"type":"function","title":"BeamCampus.ColorFuncs.bright_white_on_black/0","doc":"","ref":"BeamCampus.ColorFuncs.html#bright_white_on_black/0"},{"type":"function","title":"BeamCampus.ColorFuncs.bright_white_on_blue/0","doc":"","ref":"BeamCampus.ColorFuncs.html#bright_white_on_blue/0"},{"type":"function","title":"BeamCampus.ColorFuncs.bright_white_on_bright_black/0","doc":"","ref":"BeamCampus.ColorFuncs.html#bright_white_on_bright_black/0"},{"type":"function","title":"BeamCampus.ColorFuncs.bright_white_on_bright_blue/0","doc":"","ref":"BeamCampus.ColorFuncs.html#bright_white_on_bright_blue/0"},{"type":"function","title":"BeamCampus.ColorFuncs.bright_white_on_bright_cyan/0","doc":"","ref":"BeamCampus.ColorFuncs.html#bright_white_on_bright_cyan/0"},{"type":"function","title":"BeamCampus.ColorFuncs.bright_white_on_bright_green/0","doc":"","ref":"BeamCampus.ColorFuncs.html#bright_white_on_bright_green/0"},{"type":"function","title":"BeamCampus.ColorFuncs.bright_white_on_bright_magenta/0","doc":"","ref":"BeamCampus.ColorFuncs.html#bright_white_on_bright_magenta/0"},{"type":"function","title":"BeamCampus.ColorFuncs.bright_white_on_bright_red/0","doc":"","ref":"BeamCampus.ColorFuncs.html#bright_white_on_bright_red/0"},{"type":"function","title":"BeamCampus.ColorFuncs.bright_white_on_bright_white/0","doc":"","ref":"BeamCampus.ColorFuncs.html#bright_white_on_bright_white/0"},{"type":"function","title":"BeamCampus.ColorFuncs.bright_white_on_bright_yellow/0","doc":"","ref":"BeamCampus.ColorFuncs.html#bright_white_on_bright_yellow/0"},{"type":"function","title":"BeamCampus.ColorFuncs.bright_white_on_cyan/0","doc":"","ref":"BeamCampus.ColorFuncs.html#bright_white_on_cyan/0"},{"type":"function","title":"BeamCampus.ColorFuncs.bright_white_on_green/0","doc":"","ref":"BeamCampus.ColorFuncs.html#bright_white_on_green/0"},{"type":"function","title":"BeamCampus.ColorFuncs.bright_white_on_magenta/0","doc":"","ref":"BeamCampus.ColorFuncs.html#bright_white_on_magenta/0"},{"type":"function","title":"BeamCampus.ColorFuncs.bright_white_on_red/0","doc":"","ref":"BeamCampus.ColorFuncs.html#bright_white_on_red/0"},{"type":"function","title":"BeamCampus.ColorFuncs.bright_white_on_white/0","doc":"","ref":"BeamCampus.ColorFuncs.html#bright_white_on_white/0"},{"type":"function","title":"BeamCampus.ColorFuncs.bright_white_on_yellow/0","doc":"","ref":"BeamCampus.ColorFuncs.html#bright_white_on_yellow/0"},{"type":"function","title":"BeamCampus.ColorFuncs.bright_yellow_on_black/0","doc":"","ref":"BeamCampus.ColorFuncs.html#bright_yellow_on_black/0"},{"type":"function","title":"BeamCampus.ColorFuncs.bright_yellow_on_blue/0","doc":"","ref":"BeamCampus.ColorFuncs.html#bright_yellow_on_blue/0"},{"type":"function","title":"BeamCampus.ColorFuncs.bright_yellow_on_bright_black/0","doc":"","ref":"BeamCampus.ColorFuncs.html#bright_yellow_on_bright_black/0"},{"type":"function","title":"BeamCampus.ColorFuncs.bright_yellow_on_bright_blue/0","doc":"","ref":"BeamCampus.ColorFuncs.html#bright_yellow_on_bright_blue/0"},{"type":"function","title":"BeamCampus.ColorFuncs.bright_yellow_on_bright_cyan/0","doc":"","ref":"BeamCampus.ColorFuncs.html#bright_yellow_on_bright_cyan/0"},{"type":"function","title":"BeamCampus.ColorFuncs.bright_yellow_on_bright_green/0","doc":"","ref":"BeamCampus.ColorFuncs.html#bright_yellow_on_bright_green/0"},{"type":"function","title":"BeamCampus.ColorFuncs.bright_yellow_on_bright_magenta/0","doc":"","ref":"BeamCampus.ColorFuncs.html#bright_yellow_on_bright_magenta/0"},{"type":"function","title":"BeamCampus.ColorFuncs.bright_yellow_on_bright_red/0","doc":"","ref":"BeamCampus.ColorFuncs.html#bright_yellow_on_bright_red/0"},{"type":"function","title":"BeamCampus.ColorFuncs.bright_yellow_on_bright_white/0","doc":"","ref":"BeamCampus.ColorFuncs.html#bright_yellow_on_bright_white/0"},{"type":"function","title":"BeamCampus.ColorFuncs.bright_yellow_on_bright_yellow/0","doc":"","ref":"BeamCampus.ColorFuncs.html#bright_yellow_on_bright_yellow/0"},{"type":"function","title":"BeamCampus.ColorFuncs.bright_yellow_on_cyan/0","doc":"","ref":"BeamCampus.ColorFuncs.html#bright_yellow_on_cyan/0"},{"type":"function","title":"BeamCampus.ColorFuncs.bright_yellow_on_green/0","doc":"","ref":"BeamCampus.ColorFuncs.html#bright_yellow_on_green/0"},{"type":"function","title":"BeamCampus.ColorFuncs.bright_yellow_on_magenta/0","doc":"","ref":"BeamCampus.ColorFuncs.html#bright_yellow_on_magenta/0"},{"type":"function","title":"BeamCampus.ColorFuncs.bright_yellow_on_red/0","doc":"","ref":"BeamCampus.ColorFuncs.html#bright_yellow_on_red/0"},{"type":"function","title":"BeamCampus.ColorFuncs.bright_yellow_on_white/0","doc":"","ref":"BeamCampus.ColorFuncs.html#bright_yellow_on_white/0"},{"type":"function","title":"BeamCampus.ColorFuncs.bright_yellow_on_yellow/0","doc":"","ref":"BeamCampus.ColorFuncs.html#bright_yellow_on_yellow/0"},{"type":"function","title":"BeamCampus.ColorFuncs.cyan_on_black/0","doc":"","ref":"BeamCampus.ColorFuncs.html#cyan_on_black/0"},{"type":"function","title":"BeamCampus.ColorFuncs.cyan_on_blue/0","doc":"","ref":"BeamCampus.ColorFuncs.html#cyan_on_blue/0"},{"type":"function","title":"BeamCampus.ColorFuncs.cyan_on_bright_black/0","doc":"","ref":"BeamCampus.ColorFuncs.html#cyan_on_bright_black/0"},{"type":"function","title":"BeamCampus.ColorFuncs.cyan_on_bright_blue/0","doc":"","ref":"BeamCampus.ColorFuncs.html#cyan_on_bright_blue/0"},{"type":"function","title":"BeamCampus.ColorFuncs.cyan_on_bright_cyan/0","doc":"","ref":"BeamCampus.ColorFuncs.html#cyan_on_bright_cyan/0"},{"type":"function","title":"BeamCampus.ColorFuncs.cyan_on_bright_green/0","doc":"","ref":"BeamCampus.ColorFuncs.html#cyan_on_bright_green/0"},{"type":"function","title":"BeamCampus.ColorFuncs.cyan_on_bright_magenta/0","doc":"","ref":"BeamCampus.ColorFuncs.html#cyan_on_bright_magenta/0"},{"type":"function","title":"BeamCampus.ColorFuncs.cyan_on_bright_red/0","doc":"","ref":"BeamCampus.ColorFuncs.html#cyan_on_bright_red/0"},{"type":"function","title":"BeamCampus.ColorFuncs.cyan_on_bright_white/0","doc":"","ref":"BeamCampus.ColorFuncs.html#cyan_on_bright_white/0"},{"type":"function","title":"BeamCampus.ColorFuncs.cyan_on_bright_yellow/0","doc":"","ref":"BeamCampus.ColorFuncs.html#cyan_on_bright_yellow/0"},{"type":"function","title":"BeamCampus.ColorFuncs.cyan_on_cyan/0","doc":"","ref":"BeamCampus.ColorFuncs.html#cyan_on_cyan/0"},{"type":"function","title":"BeamCampus.ColorFuncs.cyan_on_green/0","doc":"","ref":"BeamCampus.ColorFuncs.html#cyan_on_green/0"},{"type":"function","title":"BeamCampus.ColorFuncs.cyan_on_magenta/0","doc":"","ref":"BeamCampus.ColorFuncs.html#cyan_on_magenta/0"},{"type":"function","title":"BeamCampus.ColorFuncs.cyan_on_red/0","doc":"","ref":"BeamCampus.ColorFuncs.html#cyan_on_red/0"},{"type":"function","title":"BeamCampus.ColorFuncs.cyan_on_white/0","doc":"","ref":"BeamCampus.ColorFuncs.html#cyan_on_white/0"},{"type":"function","title":"BeamCampus.ColorFuncs.cyan_on_yellow/0","doc":"","ref":"BeamCampus.ColorFuncs.html#cyan_on_yellow/0"},{"type":"function","title":"BeamCampus.ColorFuncs.green_on_black/0","doc":"","ref":"BeamCampus.ColorFuncs.html#green_on_black/0"},{"type":"function","title":"BeamCampus.ColorFuncs.green_on_blue/0","doc":"","ref":"BeamCampus.ColorFuncs.html#green_on_blue/0"},{"type":"function","title":"BeamCampus.ColorFuncs.green_on_bright_black/0","doc":"","ref":"BeamCampus.ColorFuncs.html#green_on_bright_black/0"},{"type":"function","title":"BeamCampus.ColorFuncs.green_on_bright_blue/0","doc":"","ref":"BeamCampus.ColorFuncs.html#green_on_bright_blue/0"},{"type":"function","title":"BeamCampus.ColorFuncs.green_on_bright_cyan/0","doc":"","ref":"BeamCampus.ColorFuncs.html#green_on_bright_cyan/0"},{"type":"function","title":"BeamCampus.ColorFuncs.green_on_bright_green/0","doc":"","ref":"BeamCampus.ColorFuncs.html#green_on_bright_green/0"},{"type":"function","title":"BeamCampus.ColorFuncs.green_on_bright_magenta/0","doc":"","ref":"BeamCampus.ColorFuncs.html#green_on_bright_magenta/0"},{"type":"function","title":"BeamCampus.ColorFuncs.green_on_bright_red/0","doc":"","ref":"BeamCampus.ColorFuncs.html#green_on_bright_red/0"},{"type":"function","title":"BeamCampus.ColorFuncs.green_on_bright_white/0","doc":"","ref":"BeamCampus.ColorFuncs.html#green_on_bright_white/0"},{"type":"function","title":"BeamCampus.ColorFuncs.green_on_bright_yellow/0","doc":"","ref":"BeamCampus.ColorFuncs.html#green_on_bright_yellow/0"},{"type":"function","title":"BeamCampus.ColorFuncs.green_on_cyan/0","doc":"","ref":"BeamCampus.ColorFuncs.html#green_on_cyan/0"},{"type":"function","title":"BeamCampus.ColorFuncs.green_on_green/0","doc":"","ref":"BeamCampus.ColorFuncs.html#green_on_green/0"},{"type":"function","title":"BeamCampus.ColorFuncs.green_on_magenta/0","doc":"","ref":"BeamCampus.ColorFuncs.html#green_on_magenta/0"},{"type":"function","title":"BeamCampus.ColorFuncs.green_on_red/0","doc":"","ref":"BeamCampus.ColorFuncs.html#green_on_red/0"},{"type":"function","title":"BeamCampus.ColorFuncs.green_on_white/0","doc":"","ref":"BeamCampus.ColorFuncs.html#green_on_white/0"},{"type":"function","title":"BeamCampus.ColorFuncs.green_on_yellow/0","doc":"","ref":"BeamCampus.ColorFuncs.html#green_on_yellow/0"},{"type":"function","title":"BeamCampus.ColorFuncs.magenta_on_black/0","doc":"","ref":"BeamCampus.ColorFuncs.html#magenta_on_black/0"},{"type":"function","title":"BeamCampus.ColorFuncs.magenta_on_blue/0","doc":"","ref":"BeamCampus.ColorFuncs.html#magenta_on_blue/0"},{"type":"function","title":"BeamCampus.ColorFuncs.magenta_on_bright_black/0","doc":"","ref":"BeamCampus.ColorFuncs.html#magenta_on_bright_black/0"},{"type":"function","title":"BeamCampus.ColorFuncs.magenta_on_bright_blue/0","doc":"","ref":"BeamCampus.ColorFuncs.html#magenta_on_bright_blue/0"},{"type":"function","title":"BeamCampus.ColorFuncs.magenta_on_bright_cyan/0","doc":"","ref":"BeamCampus.ColorFuncs.html#magenta_on_bright_cyan/0"},{"type":"function","title":"BeamCampus.ColorFuncs.magenta_on_bright_green/0","doc":"","ref":"BeamCampus.ColorFuncs.html#magenta_on_bright_green/0"},{"type":"function","title":"BeamCampus.ColorFuncs.magenta_on_bright_magenta/0","doc":"","ref":"BeamCampus.ColorFuncs.html#magenta_on_bright_magenta/0"},{"type":"function","title":"BeamCampus.ColorFuncs.magenta_on_bright_red/0","doc":"","ref":"BeamCampus.ColorFuncs.html#magenta_on_bright_red/0"},{"type":"function","title":"BeamCampus.ColorFuncs.magenta_on_bright_white/0","doc":"","ref":"BeamCampus.ColorFuncs.html#magenta_on_bright_white/0"},{"type":"function","title":"BeamCampus.ColorFuncs.magenta_on_bright_yellow/0","doc":"","ref":"BeamCampus.ColorFuncs.html#magenta_on_bright_yellow/0"},{"type":"function","title":"BeamCampus.ColorFuncs.magenta_on_cyan/0","doc":"","ref":"BeamCampus.ColorFuncs.html#magenta_on_cyan/0"},{"type":"function","title":"BeamCampus.ColorFuncs.magenta_on_green/0","doc":"","ref":"BeamCampus.ColorFuncs.html#magenta_on_green/0"},{"type":"function","title":"BeamCampus.ColorFuncs.magenta_on_magenta/0","doc":"","ref":"BeamCampus.ColorFuncs.html#magenta_on_magenta/0"},{"type":"function","title":"BeamCampus.ColorFuncs.magenta_on_red/0","doc":"","ref":"BeamCampus.ColorFuncs.html#magenta_on_red/0"},{"type":"function","title":"BeamCampus.ColorFuncs.magenta_on_white/0","doc":"","ref":"BeamCampus.ColorFuncs.html#magenta_on_white/0"},{"type":"function","title":"BeamCampus.ColorFuncs.magenta_on_yellow/0","doc":"","ref":"BeamCampus.ColorFuncs.html#magenta_on_yellow/0"},{"type":"function","title":"BeamCampus.ColorFuncs.red_on_black/0","doc":"","ref":"BeamCampus.ColorFuncs.html#red_on_black/0"},{"type":"function","title":"BeamCampus.ColorFuncs.red_on_blue/0","doc":"","ref":"BeamCampus.ColorFuncs.html#red_on_blue/0"},{"type":"function","title":"BeamCampus.ColorFuncs.red_on_bright_black/0","doc":"","ref":"BeamCampus.ColorFuncs.html#red_on_bright_black/0"},{"type":"function","title":"BeamCampus.ColorFuncs.red_on_bright_blue/0","doc":"","ref":"BeamCampus.ColorFuncs.html#red_on_bright_blue/0"},{"type":"function","title":"BeamCampus.ColorFuncs.red_on_bright_cyan/0","doc":"","ref":"BeamCampus.ColorFuncs.html#red_on_bright_cyan/0"},{"type":"function","title":"BeamCampus.ColorFuncs.red_on_bright_green/0","doc":"","ref":"BeamCampus.ColorFuncs.html#red_on_bright_green/0"},{"type":"function","title":"BeamCampus.ColorFuncs.red_on_bright_magenta/0","doc":"","ref":"BeamCampus.ColorFuncs.html#red_on_bright_magenta/0"},{"type":"function","title":"BeamCampus.ColorFuncs.red_on_bright_red/0","doc":"","ref":"BeamCampus.ColorFuncs.html#red_on_bright_red/0"},{"type":"function","title":"BeamCampus.ColorFuncs.red_on_bright_white/0","doc":"","ref":"BeamCampus.ColorFuncs.html#red_on_bright_white/0"},{"type":"function","title":"BeamCampus.ColorFuncs.red_on_bright_yellow/0","doc":"","ref":"BeamCampus.ColorFuncs.html#red_on_bright_yellow/0"},{"type":"function","title":"BeamCampus.ColorFuncs.red_on_cyan/0","doc":"","ref":"BeamCampus.ColorFuncs.html#red_on_cyan/0"},{"type":"function","title":"BeamCampus.ColorFuncs.red_on_green/0","doc":"","ref":"BeamCampus.ColorFuncs.html#red_on_green/0"},{"type":"function","title":"BeamCampus.ColorFuncs.red_on_magenta/0","doc":"","ref":"BeamCampus.ColorFuncs.html#red_on_magenta/0"},{"type":"function","title":"BeamCampus.ColorFuncs.red_on_red/0","doc":"","ref":"BeamCampus.ColorFuncs.html#red_on_red/0"},{"type":"function","title":"BeamCampus.ColorFuncs.red_on_white/0","doc":"","ref":"BeamCampus.ColorFuncs.html#red_on_white/0"},{"type":"function","title":"BeamCampus.ColorFuncs.red_on_yellow/0","doc":"","ref":"BeamCampus.ColorFuncs.html#red_on_yellow/0"},{"type":"function","title":"BeamCampus.ColorFuncs.reset/0","doc":"","ref":"BeamCampus.ColorFuncs.html#reset/0"},{"type":"function","title":"BeamCampus.ColorFuncs.tui/3","doc":"","ref":"BeamCampus.ColorFuncs.html#tui/3"},{"type":"function","title":"BeamCampus.ColorFuncs.white_on_black/0","doc":"","ref":"BeamCampus.ColorFuncs.html#white_on_black/0"},{"type":"function","title":"BeamCampus.ColorFuncs.white_on_blue/0","doc":"","ref":"BeamCampus.ColorFuncs.html#white_on_blue/0"},{"type":"function","title":"BeamCampus.ColorFuncs.white_on_bright_black/0","doc":"","ref":"BeamCampus.ColorFuncs.html#white_on_bright_black/0"},{"type":"function","title":"BeamCampus.ColorFuncs.white_on_bright_blue/0","doc":"","ref":"BeamCampus.ColorFuncs.html#white_on_bright_blue/0"},{"type":"function","title":"BeamCampus.ColorFuncs.white_on_bright_cyan/0","doc":"","ref":"BeamCampus.ColorFuncs.html#white_on_bright_cyan/0"},{"type":"function","title":"BeamCampus.ColorFuncs.white_on_bright_green/0","doc":"","ref":"BeamCampus.ColorFuncs.html#white_on_bright_green/0"},{"type":"function","title":"BeamCampus.ColorFuncs.white_on_bright_magenta/0","doc":"","ref":"BeamCampus.ColorFuncs.html#white_on_bright_magenta/0"},{"type":"function","title":"BeamCampus.ColorFuncs.white_on_bright_red/0","doc":"","ref":"BeamCampus.ColorFuncs.html#white_on_bright_red/0"},{"type":"function","title":"BeamCampus.ColorFuncs.white_on_bright_white/0","doc":"","ref":"BeamCampus.ColorFuncs.html#white_on_bright_white/0"},{"type":"function","title":"BeamCampus.ColorFuncs.white_on_bright_yellow/0","doc":"","ref":"BeamCampus.ColorFuncs.html#white_on_bright_yellow/0"},{"type":"function","title":"BeamCampus.ColorFuncs.white_on_cyan/0","doc":"","ref":"BeamCampus.ColorFuncs.html#white_on_cyan/0"},{"type":"function","title":"BeamCampus.ColorFuncs.white_on_green/0","doc":"","ref":"BeamCampus.ColorFuncs.html#white_on_green/0"},{"type":"function","title":"BeamCampus.ColorFuncs.white_on_magenta/0","doc":"","ref":"BeamCampus.ColorFuncs.html#white_on_magenta/0"},{"type":"function","title":"BeamCampus.ColorFuncs.white_on_red/0","doc":"","ref":"BeamCampus.ColorFuncs.html#white_on_red/0"},{"type":"function","title":"BeamCampus.ColorFuncs.white_on_white/0","doc":"","ref":"BeamCampus.ColorFuncs.html#white_on_white/0"},{"type":"function","title":"BeamCampus.ColorFuncs.white_on_yellow/0","doc":"","ref":"BeamCampus.ColorFuncs.html#white_on_yellow/0"},{"type":"function","title":"BeamCampus.ColorFuncs.yellow_on_black/0","doc":"","ref":"BeamCampus.ColorFuncs.html#yellow_on_black/0"},{"type":"function","title":"BeamCampus.ColorFuncs.yellow_on_blue/0","doc":"","ref":"BeamCampus.ColorFuncs.html#yellow_on_blue/0"},{"type":"function","title":"BeamCampus.ColorFuncs.yellow_on_bright_black/0","doc":"","ref":"BeamCampus.ColorFuncs.html#yellow_on_bright_black/0"},{"type":"function","title":"BeamCampus.ColorFuncs.yellow_on_bright_blue/0","doc":"","ref":"BeamCampus.ColorFuncs.html#yellow_on_bright_blue/0"},{"type":"function","title":"BeamCampus.ColorFuncs.yellow_on_bright_cyan/0","doc":"","ref":"BeamCampus.ColorFuncs.html#yellow_on_bright_cyan/0"},{"type":"function","title":"BeamCampus.ColorFuncs.yellow_on_bright_green/0","doc":"","ref":"BeamCampus.ColorFuncs.html#yellow_on_bright_green/0"},{"type":"function","title":"BeamCampus.ColorFuncs.yellow_on_bright_magenta/0","doc":"","ref":"BeamCampus.ColorFuncs.html#yellow_on_bright_magenta/0"},{"type":"function","title":"BeamCampus.ColorFuncs.yellow_on_bright_red/0","doc":"","ref":"BeamCampus.ColorFuncs.html#yellow_on_bright_red/0"},{"type":"function","title":"BeamCampus.ColorFuncs.yellow_on_bright_white/0","doc":"","ref":"BeamCampus.ColorFuncs.html#yellow_on_bright_white/0"},{"type":"function","title":"BeamCampus.ColorFuncs.yellow_on_bright_yellow/0","doc":"","ref":"BeamCampus.ColorFuncs.html#yellow_on_bright_yellow/0"},{"type":"function","title":"BeamCampus.ColorFuncs.yellow_on_cyan/0","doc":"","ref":"BeamCampus.ColorFuncs.html#yellow_on_cyan/0"},{"type":"function","title":"BeamCampus.ColorFuncs.yellow_on_green/0","doc":"","ref":"BeamCampus.ColorFuncs.html#yellow_on_green/0"},{"type":"function","title":"BeamCampus.ColorFuncs.yellow_on_magenta/0","doc":"","ref":"BeamCampus.ColorFuncs.html#yellow_on_magenta/0"},{"type":"function","title":"BeamCampus.ColorFuncs.yellow_on_red/0","doc":"","ref":"BeamCampus.ColorFuncs.html#yellow_on_red/0"},{"type":"function","title":"BeamCampus.ColorFuncs.yellow_on_white/0","doc":"","ref":"BeamCampus.ColorFuncs.html#yellow_on_white/0"},{"type":"function","title":"BeamCampus.ColorFuncs.yellow_on_yellow/0","doc":"","ref":"BeamCampus.ColorFuncs.html#yellow_on_yellow/0"},{"type":"module","title":"ExESDB","doc":"ExESDB is a wrapper around the khepri library. \n  Its intention is to provide an interface to khepri,\n  with a focus on event sourcing.","ref":"ExESDB.html"},{"type":"module","title":"ExESDB.Aggregator","doc":"Aggregates events from an event stream using tagged rules:\n  GIVEN: an Event of roughly this format:\n   %{\n    event_id: \"1234567890\",\n    event_type: \"user.birthday_celebrated:v1\",\n    stream_id: \"celebrate-user-birthday-john\",\n    version: 1,\n    data: %{\n      name: \"John\",\n      age: {:sum, 1},\n      venue: {:overwrite, \"New York\"}\n    },\n    timestamp: ~U[2022-01-01 12:00:00Z],\n    epoch: 1641013200,\n    metadata: %{\n      source_id: \"1234567890\"\n    }\n  }","ref":"ExESDB.Aggregator.html"},{"type":"function","title":"ExESDB.Aggregator.finalize_map/1","doc":"","ref":"ExESDB.Aggregator.html#finalize_map/1"},{"type":"function","title":"ExESDB.Aggregator.foldl/2","doc":"Folds a list of events into a single map.","ref":"ExESDB.Aggregator.html#foldl/2"},{"type":"module","title":"ExESDB.App","doc":"This module is used to start the ExESDB system.","ref":"ExESDB.App.html"},{"type":"module","title":"ExESDB.Commanded.Adapter","doc":"An adapter for Commanded to use ExESDB as the event store.\n  for reference, see: https://hexdocs.pm/commanded/Commanded.EventStore.Adapter.html","ref":"ExESDB.Commanded.Adapter.html"},{"type":"type","title":"ExESDB.Commanded.Adapter.adapter_meta/0","doc":"","ref":"ExESDB.Commanded.Adapter.html#t:adapter_meta/0"},{"type":"function","title":"ExESDB.Commanded.Adapter.append_to_stream/5","doc":"Append one or more events to a stream atomically.","ref":"ExESDB.Commanded.Adapter.html#append_to_stream/5"},{"type":"type","title":"ExESDB.Commanded.Adapter.application/0","doc":"","ref":"ExESDB.Commanded.Adapter.html#t:application/0"},{"type":"function","title":"ExESDB.Commanded.Adapter.child_spec/2","doc":"Return a child spec defining all processes required by the event store.","ref":"ExESDB.Commanded.Adapter.html#child_spec/2"},{"type":"type","title":"ExESDB.Commanded.Adapter.config/0","doc":"","ref":"ExESDB.Commanded.Adapter.html#t:config/0"},{"type":"function","title":"ExESDB.Commanded.Adapter.delete_snapshot/2","doc":"Delete a snapshot of the current state of the event store.","ref":"ExESDB.Commanded.Adapter.html#delete_snapshot/2"},{"type":"function","title":"ExESDB.Commanded.Adapter.delete_subscription/3","doc":"Delete a subscription.","ref":"ExESDB.Commanded.Adapter.html#delete_subscription/3"},{"type":"type","title":"ExESDB.Commanded.Adapter.error/0","doc":"","ref":"ExESDB.Commanded.Adapter.html#t:error/0"},{"type":"type","title":"ExESDB.Commanded.Adapter.expected_version/0","doc":"","ref":"ExESDB.Commanded.Adapter.html#t:expected_version/0"},{"type":"function","title":"ExESDB.Commanded.Adapter.record_snapshot/2","doc":"Record a snapshot of the current state of the event store.","ref":"ExESDB.Commanded.Adapter.html#record_snapshot/2"},{"type":"type","title":"ExESDB.Commanded.Adapter.source_uuid/0","doc":"","ref":"ExESDB.Commanded.Adapter.html#t:source_uuid/0"},{"type":"type","title":"ExESDB.Commanded.Adapter.start_from/0","doc":"","ref":"ExESDB.Commanded.Adapter.html#t:start_from/0"},{"type":"function","title":"ExESDB.Commanded.Adapter.stream_forward/4","doc":"Streams events from the given stream, in the order in which they were\n  originally written.","ref":"ExESDB.Commanded.Adapter.html#stream_forward/4"},{"type":"type","title":"ExESDB.Commanded.Adapter.stream_uuid/0","doc":"","ref":"ExESDB.Commanded.Adapter.html#t:stream_uuid/0"},{"type":"function","title":"ExESDB.Commanded.Adapter.subscribe/2","doc":"Create a transient subscription to a single event stream.\n\n  The event store will publish any events appended to the given stream to the\n  `subscriber` process as an `{:events, events}` message.\n\n  The subscriber does not need to acknowledge receipt of the events.","ref":"ExESDB.Commanded.Adapter.html#subscribe/2"},{"type":"function","title":"ExESDB.Commanded.Adapter.subscribe_to/6","doc":"Create a persistent subscription to an event stream.","ref":"ExESDB.Commanded.Adapter.html#subscribe_to/6"},{"type":"type","title":"ExESDB.Commanded.Adapter.subscriber/0","doc":"","ref":"ExESDB.Commanded.Adapter.html#t:subscriber/0"},{"type":"type","title":"ExESDB.Commanded.Adapter.subscription/0","doc":"","ref":"ExESDB.Commanded.Adapter.html#t:subscription/0"},{"type":"type","title":"ExESDB.Commanded.Adapter.subscription_name/0","doc":"","ref":"ExESDB.Commanded.Adapter.html#t:subscription_name/0"},{"type":"module","title":"ExESDB.Commanded.Mapper","doc":"A mapper for Commanded to use ExESDB as the event store.","ref":"ExESDB.Commanded.Mapper.html"},{"type":"function","title":"ExESDB.Commanded.Mapper.to_new_event/1","doc":"Converts a Commanded EventData struct to an ExESDB NewEvent struct.","ref":"ExESDB.Commanded.Mapper.html#to_new_event/1"},{"type":"function","title":"ExESDB.Commanded.Mapper.to_recorded_event/1","doc":"Converts an ExESDB EventRecord struct to a Commanded RecordedEvent struct.","ref":"ExESDB.Commanded.Mapper.html#to_recorded_event/1"},{"type":"function","title":"ExESDB.Commanded.Mapper.to_snapshot_data/1","doc":"Converts an ExESDB SnapshotRecord struct to a Commanded SnapshotData struct.","ref":"ExESDB.Commanded.Mapper.html#to_snapshot_data/1"},{"type":"function","title":"ExESDB.Commanded.Mapper.to_snapshot_record/1","doc":"Converts an Commanded SnapshotData struct to an ExESDB SnapshotRecord struct.","ref":"ExESDB.Commanded.Mapper.html#to_snapshot_record/1"},{"type":"module","title":"ExESDB.EmitterPool","doc":"As part of the ExESDB.System,","ref":"ExESDB.EmitterPool.html"},{"type":"function","title":"ExESDB.EmitterPool.child_spec/1","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"ExESDB.EmitterPool.html#child_spec/1"},{"type":"function","title":"ExESDB.EmitterPool.start_link/1","doc":"","ref":"ExESDB.EmitterPool.html#start_link/1"},{"type":"module","title":"ExESDB.EmitterWorker","doc":"As part of the ExESDB.System, \n  the EmitterWorker is responsible for managing the communication \n  between the Event Store and the PubSub mechanism.","ref":"ExESDB.EmitterWorker.html"},{"type":"function","title":"ExESDB.EmitterWorker.child_spec/1","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"ExESDB.EmitterWorker.html#child_spec/1"},{"type":"function","title":"ExESDB.EmitterWorker.start_link/1","doc":"","ref":"ExESDB.EmitterWorker.html#start_link/1"},{"type":"module","title":"ExESDB.Emitters","doc":"As part of the ExESDB.System, ExESDB.Emitters is responsible for managing the\n  lifetime of the Emitter processes.","ref":"ExESDB.Emitters.html"},{"type":"function","title":"ExESDB.Emitters.start_emitter/3","doc":"","ref":"ExESDB.Emitters.html#start_emitter/3"},{"type":"module","title":"ExESDB.EnVars","doc":"This module contains the environment variables that are used by ExESDB","ref":"ExESDB.EnVars.html"},{"type":"function","title":"ExESDB.EnVars.data_dir/0","doc":"Returns the data directory. default: `/data`","ref":"ExESDB.EnVars.html#data_dir/0"},{"type":"function","title":"ExESDB.EnVars.db_type/0","doc":"Returns the db type. `single` or `cluster`. default: `single`","ref":"ExESDB.EnVars.html#db_type/0"},{"type":"function","title":"ExESDB.EnVars.pub_sub/0","doc":"Returns the name of the pub/sub. default: `ex_esdb_pub_sub`","ref":"ExESDB.EnVars.html#pub_sub/0"},{"type":"function","title":"ExESDB.EnVars.seed_nodes/0","doc":"Returns the seed nodes. default: `nil`","ref":"ExESDB.EnVars.html#seed_nodes/0"},{"type":"function","title":"ExESDB.EnVars.store_id/0","doc":"Returns the khepri store id. default: `ex_esdb_store`","ref":"ExESDB.EnVars.html#store_id/0"},{"type":"function","title":"ExESDB.EnVars.timeout/0","doc":"Returns the timeout in milliseconds. default: `10_000`","ref":"ExESDB.EnVars.html#timeout/0"},{"type":"module","title":"ExESDB.EventProjector","doc":"This module contains the event projector functionality","ref":"ExESDB.EventProjector.html"},{"type":"function","title":"ExESDB.EventProjector.child_spec/1","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"ExESDB.EventProjector.html#child_spec/1"},{"type":"function","title":"ExESDB.EventProjector.start_link/1","doc":"","ref":"ExESDB.EventProjector.html#start_link/1"},{"type":"module","title":"ExESDB.Gateway","doc":"Provides API functions for working with ExESDB","ref":"ExESDB.Gateway.html"},{"type":"module","title":"API - ExESDB.Gateway","doc":"- append_events/4\n    - get_events/4\n    - get_streams/1\n\n    - add_subscription/4\n    - subscribe_to/5\n    - unsubscribe/2\n    - delete_subscription/4","ref":"ExESDB.Gateway.html#module-api"},{"type":"function","title":"ExESDB.Gateway.add_subscription/6","doc":"Add a subscription.","ref":"ExESDB.Gateway.html#add_subscription/6"},{"type":"function","title":"ExESDB.Gateway.append_events/3","doc":"","ref":"ExESDB.Gateway.html#append_events/3"},{"type":"function","title":"ExESDB.Gateway.child_spec/1","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"ExESDB.Gateway.html#child_spec/1"},{"type":"type","title":"ExESDB.Gateway.error/0","doc":"","ref":"ExESDB.Gateway.html#t:error/0"},{"type":"function","title":"ExESDB.Gateway.get_events/5","doc":"","ref":"ExESDB.Gateway.html#get_events/5"},{"type":"function","title":"ExESDB.Gateway.get_streams/1","doc":"Get all streams from the store.","ref":"ExESDB.Gateway.html#get_streams/1"},{"type":"function","title":"Parameters - ExESDB.Gateway.get_streams/1","doc":"- store: the id of the store","ref":"ExESDB.Gateway.html#get_streams/1-parameters"},{"type":"function","title":"Returns - ExESDB.Gateway.get_streams/1","doc":"- a list of all streams in the store","ref":"ExESDB.Gateway.html#get_streams/1-returns"},{"type":"function","title":"ExESDB.Gateway.get_subscriptions/1","doc":"","ref":"ExESDB.Gateway.html#get_subscriptions/1"},{"type":"function","title":"ExESDB.Gateway.remove_subscription/4","doc":"Delete a subscription.","ref":"ExESDB.Gateway.html#remove_subscription/4"},{"type":"type","title":"ExESDB.Gateway.selector_type/0","doc":"","ref":"ExESDB.Gateway.html#t:selector_type/0"},{"type":"function","title":"ExESDB.Gateway.start_link/1","doc":"","ref":"ExESDB.Gateway.html#start_link/1"},{"type":"type","title":"ExESDB.Gateway.store/0","doc":"","ref":"ExESDB.Gateway.html#t:store/0"},{"type":"type","title":"ExESDB.Gateway.stream/0","doc":"","ref":"ExESDB.Gateway.html#t:stream/0"},{"type":"type","title":"ExESDB.Gateway.subscription_name/0","doc":"","ref":"ExESDB.Gateway.html#t:subscription_name/0"},{"type":"type","title":"ExESDB.Gateway.subscription_type/0","doc":"","ref":"ExESDB.Gateway.html#t:subscription_type/0"},{"type":"module","title":"ExESDB.LeaderSystem","doc":"This module supervises the Leader Subsystem.","ref":"ExESDB.LeaderSystem.html"},{"type":"function","title":"ExESDB.LeaderSystem.child_spec/1","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"ExESDB.LeaderSystem.html#child_spec/1"},{"type":"function","title":"ExESDB.LeaderSystem.start_link/1","doc":"","ref":"ExESDB.LeaderSystem.html#start_link/1"},{"type":"module","title":"ExESDB.LeaderWorker","doc":"This module contains the leader's reponsibilities for the cluster.","ref":"ExESDB.LeaderWorker.html"},{"type":"function","title":"ExESDB.LeaderWorker.activate/1","doc":"","ref":"ExESDB.LeaderWorker.html#activate/1"},{"type":"function","title":"ExESDB.LeaderWorker.child_spec/1","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"ExESDB.LeaderWorker.html#child_spec/1"},{"type":"function","title":"ExESDB.LeaderWorker.start_link/1","doc":"","ref":"ExESDB.LeaderWorker.html#start_link/1"},{"type":"module","title":"ExESDB.Messages","doc":"Messages are based on official proto file","ref":"ExESDB.Messages.html"},{"type":"type","title":"ExESDB.Messages.t/0","doc":"","ref":"ExESDB.Messages.html#t:t/0"},{"type":"module","title":"ExESDB.Metrics","doc":"Provides metrics for the event store.","ref":"ExESDB.Metrics.html"},{"type":"module","title":"ExESDB.Options","doc":"This module contains the options helper functions for ExESDB","ref":"ExESDB.Options.html"},{"type":"function","title":"ExESDB.Options.app_env/0","doc":"","ref":"ExESDB.Options.html#app_env/0"},{"type":"function","title":"ExESDB.Options.app_env/1","doc":"","ref":"ExESDB.Options.html#app_env/1"},{"type":"function","title":"ExESDB.Options.data_dir/0","doc":"","ref":"ExESDB.Options.html#data_dir/0"},{"type":"function","title":"ExESDB.Options.db_type/0","doc":"","ref":"ExESDB.Options.html#db_type/0"},{"type":"function","title":"ExESDB.Options.pub_sub/0","doc":"","ref":"ExESDB.Options.html#pub_sub/0"},{"type":"function","title":"ExESDB.Options.seed_nodes/0","doc":"","ref":"ExESDB.Options.html#seed_nodes/0"},{"type":"function","title":"ExESDB.Options.store_id/0","doc":"","ref":"ExESDB.Options.html#store_id/0"},{"type":"function","title":"ExESDB.Options.sys_env/1","doc":"","ref":"ExESDB.Options.html#sys_env/1"},{"type":"function","title":"ExESDB.Options.timeout/0","doc":"","ref":"ExESDB.Options.html#timeout/0"},{"type":"module","title":"ExESDB.Repl","doc":"This module is to interact with the ExESDB.system, \n  running a store called \"reg_gh\" (Regulate Greenhouse)","ref":"ExESDB.Repl.html"},{"type":"function","title":"ExESDB.Repl.append/2","doc":"Append events to a stream.","ref":"ExESDB.Repl.html#append/2"},{"type":"function","title":"ExESDB.Repl.get_opts/0","doc":"","ref":"ExESDB.Repl.html#get_opts/0"},{"type":"function","title":"ExESDB.Repl.get_streams/0","doc":"","ref":"ExESDB.Repl.html#get_streams/0"},{"type":"function","title":"ExESDB.Repl.get_subscriptions/0","doc":"","ref":"ExESDB.Repl.html#get_subscriptions/0"},{"type":"function","title":"ExESDB.Repl.start_system/0","doc":"","ref":"ExESDB.Repl.html#start_system/0"},{"type":"function","title":"ExESDB.Repl.store/0","doc":"","ref":"ExESDB.Repl.html#store/0"},{"type":"function","title":"ExESDB.Repl.stream1/0","doc":"","ref":"ExESDB.Repl.html#stream1/0"},{"type":"function","title":"ExESDB.Repl.stream2/0","doc":"","ref":"ExESDB.Repl.html#stream2/0"},{"type":"function","title":"ExESDB.Repl.stream3/0","doc":"","ref":"ExESDB.Repl.html#stream3/0"},{"type":"function","title":"ExESDB.Repl.stream4/0","doc":"","ref":"ExESDB.Repl.html#stream4/0"},{"type":"function","title":"ExESDB.Repl.stream5/0","doc":"","ref":"ExESDB.Repl.html#stream5/0"},{"type":"function","title":"ExESDB.Repl.test_all_emitter/1","doc":"","ref":"ExESDB.Repl.html#test_all_emitter/1"},{"type":"function","title":"ExESDB.Repl.test_initialized_v1_emitter/1","doc":"","ref":"ExESDB.Repl.html#test_initialized_v1_emitter/1"},{"type":"module","title":"ExESDB.Schema.SnapshotRecord","doc":"A snapshot record","ref":"ExESDB.Schema.SnapshotRecord.html"},{"type":"type","title":"ExESDB.Schema.SnapshotRecord.t/0","doc":"","ref":"ExESDB.Schema.SnapshotRecord.html#t:t/0"},{"type":"module","title":"ExESDB.Snapshots","doc":"Provides functions for working with snapshots","ref":"ExESDB.Snapshots.html"},{"type":"function","title":"ExESDB.Snapshots.delete_snapshot/2","doc":"Delete a snapshot of the current state of the event store.","ref":"ExESDB.Snapshots.html#delete_snapshot/2"},{"type":"function","title":"ExESDB.Snapshots.read_snapshot/2","doc":"Read a snapshot of the current state of the event store.","ref":"ExESDB.Snapshots.html#read_snapshot/2"},{"type":"function","title":"ExESDB.Snapshots.record_snapshot/2","doc":"Record a snapshot of the current state of the event store.","ref":"ExESDB.Snapshots.html#record_snapshot/2"},{"type":"module","title":"ExESDB.Store","doc":"A GenServer wrapper around :khepri to act as a distributed event store.\n  Inspired by EventStoreDB's API.","ref":"ExESDB.Store.html"},{"type":"function","title":"ExESDB.Store.child_spec/1","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"ExESDB.Store.html#child_spec/1"},{"type":"function","title":"ExESDB.Store.get_state/0","doc":"Get the current state of the store.","ref":"ExESDB.Store.html#get_state/0"},{"type":"function","title":"Returns - ExESDB.Store.get_state/0","doc":"- `{:ok, state}`  if successful.\n    - `{:error, reason}` if unsuccessful.","ref":"ExESDB.Store.html#get_state/0-returns"},{"type":"function","title":"ExESDB.Store.start_link/1","doc":"","ref":"ExESDB.Store.html#start_link/1"},{"type":"module","title":"ExESDB.StoreInfo","doc":"This module provides functions to get information about the EXESDB event store.","ref":"ExESDB.StoreInfo.html"},{"type":"function","title":"ExESDB.StoreInfo.get_streams!/1","doc":"Returns the list of streams in the store.","ref":"ExESDB.StoreInfo.html#get_streams!/1"},{"type":"function","title":"ExESDB.StoreInfo.get_streams_raw/1","doc":"","ref":"ExESDB.StoreInfo.html#get_streams_raw/1"},{"type":"module","title":"ExESDB.Streams","doc":"The ExESDB Streams SubSystem.","ref":"ExESDB.Streams.html"},{"type":"function","title":"ExESDB.Streams.child_spec/1","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"ExESDB.Streams.html#child_spec/1"},{"type":"function","title":"ExESDB.Streams.start_link/1","doc":"","ref":"ExESDB.Streams.html#start_link/1"},{"type":"module","title":"ExESDB.StreamsHelper","doc":"Provides helper functions for working with event store streams.","ref":"ExESDB.StreamsHelper.html"},{"type":"function","title":"ExESDB.StreamsHelper.calculate_versions/3","doc":"","ref":"ExESDB.StreamsHelper.html#calculate_versions/3"},{"type":"function","title":"ExESDB.StreamsHelper.get_version!/2","doc":"Returns the version of the stream.","ref":"ExESDB.StreamsHelper.html#get_version!/2"},{"type":"function","title":"Parameters - ExESDB.StreamsHelper.get_version!/2","doc":"- `store` is the name of the store.\n   - `stream_id` is the name of the stream.","ref":"ExESDB.StreamsHelper.html#get_version!/2-parameters"},{"type":"function","title":"Returns - ExESDB.StreamsHelper.get_version!/2","doc":"- `version`  or `0` if the stream does not exist.","ref":"ExESDB.StreamsHelper.html#get_version!/2-returns"},{"type":"function","title":"ExESDB.StreamsHelper.pad_version/2","doc":"","ref":"ExESDB.StreamsHelper.html#pad_version/2"},{"type":"function","title":"ExESDB.StreamsHelper.stream_exists?/2","doc":"","ref":"ExESDB.StreamsHelper.html#stream_exists?/2"},{"type":"function","title":"ExESDB.StreamsHelper.to_event_record/5","doc":"","ref":"ExESDB.StreamsHelper.html#to_event_record/5"},{"type":"function","title":"ExESDB.StreamsHelper.version_to_integer/1","doc":"","ref":"ExESDB.StreamsHelper.html#version_to_integer/1"},{"type":"module","title":"ExESDB.StreamsReader","doc":"Provides functions for reading and streaming events from the event store.","ref":"ExESDB.StreamsReader.html"},{"type":"function","title":"ExESDB.StreamsReader.child_spec/1","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"ExESDB.StreamsReader.html#child_spec/1"},{"type":"function","title":"ExESDB.StreamsReader.get_streams/1","doc":"Returns a list of all streams in the store.","ref":"ExESDB.StreamsReader.html#get_streams/1"},{"type":"function","title":"Parameters - ExESDB.StreamsReader.get_streams/1","doc":"#  - `store` is the name of the store.","ref":"ExESDB.StreamsReader.html#get_streams/1-parameters"},{"type":"function","title":"Returns - ExESDB.StreamsReader.get_streams/1","doc":"#  - `{:ok, streams}`  if successful.","ref":"ExESDB.StreamsReader.html#get_streams/1-returns"},{"type":"function","title":"ExESDB.StreamsReader.start_link/1","doc":"","ref":"ExESDB.StreamsReader.html#start_link/1"},{"type":"function","title":"ExESDB.StreamsReader.stream_events/5","doc":"Streams events from `stream` in batches of `count` events, in a `direction`.","ref":"ExESDB.StreamsReader.html#stream_events/5"},{"type":"module","title":"ExESDB.StreamsWriter","doc":"Provides functions for writing streams","ref":"ExESDB.StreamsWriter.html"},{"type":"function","title":"ExESDB.StreamsWriter.append_events/4","doc":"Append events to a stream.","ref":"ExESDB.StreamsWriter.html#append_events/4"},{"type":"function","title":"ExESDB.StreamsWriter.child_spec/1","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"ExESDB.StreamsWriter.html#child_spec/1"},{"type":"function","title":"ExESDB.StreamsWriter.start_link/1","doc":"","ref":"ExESDB.StreamsWriter.html#start_link/1"},{"type":"module","title":"ExESDB.Subscriptions","doc":"Provides functions for working with event store subscriptions.","ref":"ExESDB.Subscriptions.html"},{"type":"function","title":"ExESDB.Subscriptions.child_spec/1","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"ExESDB.Subscriptions.html#child_spec/1"},{"type":"function","title":"ExESDB.Subscriptions.start_link/1","doc":"","ref":"ExESDB.Subscriptions.html#start_link/1"},{"type":"module","title":"ExESDB.SubscriptionsReader","doc":"Provides functions for working with event store subscriptions.","ref":"ExESDB.SubscriptionsReader.html"},{"type":"function","title":"ExESDB.SubscriptionsReader.child_spec/1","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"ExESDB.SubscriptionsReader.html#child_spec/1"},{"type":"function","title":"ExESDB.SubscriptionsReader.get_subscriptions/1","doc":"","ref":"ExESDB.SubscriptionsReader.html#get_subscriptions/1"},{"type":"function","title":"ExESDB.SubscriptionsReader.start_link/1","doc":"","ref":"ExESDB.SubscriptionsReader.html#start_link/1"},{"type":"module","title":"ExESDB.SubscriptionsTracker","doc":"As part of the ExESDB.System, the SubscriptionsTracker is responsible for\n  observing the subscriptions that are maintained in the Store.\n\n  Since Khepri triggers are executed on the leader node, the SubscriptionsTracker\n  will be instructed to start the Emitters system on the leader node whenever a new subscription\n  is registered.\n\n  When a Subscription is deleted, the SubscriptionsTracker will instruct the Emitters system to stop \n  the associated EmitterPool.","ref":"ExESDB.SubscriptionsTracker.html"},{"type":"function","title":"ExESDB.SubscriptionsTracker.child_spec/1","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"ExESDB.SubscriptionsTracker.html#child_spec/1"},{"type":"function","title":"ExESDB.SubscriptionsTracker.start_link/1","doc":"","ref":"ExESDB.SubscriptionsTracker.html#start_link/1"},{"type":"module","title":"ExESDB.SubscriptionsWriter","doc":"Provides functions for working with event store subscriptions.","ref":"ExESDB.SubscriptionsWriter.html"},{"type":"function","title":"ExESDB.SubscriptionsWriter.child_spec/1","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"ExESDB.SubscriptionsWriter.html#child_spec/1"},{"type":"function","title":"ExESDB.SubscriptionsWriter.delete_subscription/4","doc":"","ref":"ExESDB.SubscriptionsWriter.html#delete_subscription/4"},{"type":"function","title":"ExESDB.SubscriptionsWriter.put_subscription/6","doc":"","ref":"ExESDB.SubscriptionsWriter.html#put_subscription/6"},{"type":"function","title":"ExESDB.SubscriptionsWriter.start_link/1","doc":"","ref":"ExESDB.SubscriptionsWriter.html#start_link/1"},{"type":"module","title":"ExESDB.System","doc":"This module is the top level supervisor for the ExESDB system.\n  It is responsible for supervising:\n  - The PubSub mechanism\n  - the Event Store (starts and stops khepri)\n  - the Cluster (joins and leaves the cluster)\n  - the Leader (manages Ra leader-specific functionality)\n  - the Subscriptions Supervisor (manages subscriptions)","ref":"ExESDB.System.html"},{"type":"function","title":"ExESDB.System.child_spec/1","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"ExESDB.System.html#child_spec/1"},{"type":"function","title":"ExESDB.System.start/1","doc":"","ref":"ExESDB.System.html#start/1"},{"type":"function","title":"ExESDB.System.start_link/1","doc":"","ref":"ExESDB.System.html#start_link/1"},{"type":"function","title":"ExESDB.System.stop/1","doc":"","ref":"ExESDB.System.html#stop/1"},{"type":"extras","title":"Architecture Decision Records","doc":"# Architecture Decision Records","ref":"adr.html"},{"type":"extras","title":"2025.05.24 - Architecture Decision Records","doc":"","ref":"adr.html#2025-05-24"},{"type":"extras","title":"Emitter pools must run on the Ra leader. - Architecture Decision Records","doc":"Given that Khepri triggers are executed on the Ra leader, emitter pools must run on the Ra leader.\nIn order to achieve this, it is necessary that a separate process existst, that monitors the Cluster and subscribes to Ra's leadership changes, by starting relevant emitter pools on the new leader.","ref":"adr.html#emitter-pools-must-run-on-the-ra-leader"},{"type":"extras","title":"2025.05.02 - Architecture Decision Records","doc":"","ref":"adr.html#2025-05-02"},{"type":"extras","title":"Triggers will obtain Emitter Pids from :pg (Process Groups) - Architecture Decision Records","doc":"Experimentation with :khepri's trigger model has shown that it is advised to use as few dependencies as possible, when defining the trigger functions. This is because :khepri uses :horus to decompile such functions and build a separate module. For this reason, we limit the dependencies for these trigger functions to :pg (Process Groups), which is an :erlang native module that allows for inter-process communication.","ref":"adr.html#triggers-will-obtain-emitter-pids-from-pg-process-groups"},{"type":"extras","title":"2025.04.16 - Architecture Decision Records","doc":"","ref":"adr.html#2025-04-16"},{"type":"extras","title":"Subscriptions will be managed via a registry. - Architecture Decision Records","doc":"`subscribe_to` and `unsubscribe` will interact with the :subscriptions branch of the store, but instead of storing the pid of the subscriber, the subscriber will be stored in a registry.","ref":"adr.html#subscriptions-will-be-managed-via-a-registry"},{"type":"extras","title":"2025.04.13 - Architecture Decision Records","doc":"","ref":"adr.html#2025-04-13"},{"type":"extras","title":"Each Store will contain separate branches for Streams, Subscriptions, and Projections - Architecture Decision Records","doc":"- `:streams` will be used to store the events that are being read from and written to the store.\n- `:subscriptions` will be used to store the subscription information of so-called `Persistent Subscriptions`.\n- `:projections` can best be thought of as stored procedures that are used to transform the events in the `Streams` into a different format or to enrich the streams with secondary or derived events, to name a few possible use cases.\n\nThus:\n\n```mono\n:khepri\n  |\n  +-:manage_orders\n      |\n      +-:streams\n      |\n      +-:subscriptions\n      |\n      +-:projections\n```","ref":"adr.html#each-store-will-contain-separate-branches-for-streams-subscriptions-and-projections"},{"type":"extras","title":"Changelog","doc":"# Changelog","ref":"changelog.html"},{"type":"extras","title":"version 0.0.9-alpha - Changelog","doc":"","ref":"changelog.html#version-0-0-9-alpha"},{"type":"extras","title":"2025.05.04 - Changelog","doc":"#### Added support for Subscriptions\n\n- `ExESDB.Subscriptions` module\n- `func_registrations.exs` file\n- emitter trigger in `khepri` now only uses the `erlang`-native :pg library (process groups)\n\n#### Added support for Commanded\n\n- `ExESDB.Commanded.Adapter` module\n- `ExESDB.Commanded.Mapper` module","ref":"changelog.html#2025-05-04"},{"type":"extras","title":"version 0.0.8-alpha - Changelog","doc":"","ref":"changelog.html#version-0-0-8-alpha"},{"type":"extras","title":"2025.04.13 - Changelog","doc":"- Added `ExESDB.EventStore.stream_forward/4` function\n- Added `BeamCampus.ColorFuncs` module\n- Added `ExESDB.Commanded.Adapter` module\n- Refactored `ExESDB.EventStreamReader` and `ExESDB.EventStreamWriter` modules:\n- Streams are now read and written using the `ExESDB.Streams` module\n- Removed `ExESDB.EventStreamReader` module\n- Removed `ExESDB.EventStreamWriter` module","ref":"changelog.html#2025-04-13"},{"type":"extras","title":"version 0.0.7-alpha - Changelog","doc":"","ref":"changelog.html#version-0-0-7-alpha"},{"type":"extras","title":"version 0.0.1-alpha - Changelog","doc":"","ref":"changelog.html#version-0-0-1-alpha"},{"type":"extras","title":"2025.03.25 - Changelog","doc":"- Initial release","ref":"changelog.html#2025-03-25"},{"type":"extras","title":"Getting Started","doc":"# Getting Started with ExESDB","ref":"getting-started.html"},{"type":"extras","title":"Introduction - Getting Started","doc":"Event Sourcing with CQRS is a technique for building applications that are based on an immutable log of events, which makes it ideal for building concurrent, distributed systems.\n\nThough it is gaining popularity, the number of options for storing these events is limited and require specialized services like Kurrent (aka Greg's EventStore) or AxonIQ.\n\nOne of the strong-points of the BEAM is, that it comes 'batteries included': there are BEAM-native libraries for many common tasks, like: storage, pub/sub, caching, logging, telemetry, etc.\n\n`ExESDB` is an attempt to create a BEAM-native Event Store written in Elixir, building further upon the [Khepri](https://github.com/rabbitmq/khepri) library, which in turn builds upon the [Ra](https://github.com/rabbitmq/ra) library.","ref":"getting-started.html#introduction"},{"type":"extras","title":"Status - Getting Started","doc":"**This is a work in progress**\n\nThe project is in an early stage of development, and is not ready for production use.\n\nSource code is available on [GitHub](https://github.com/beam-campus/ex-esdb).","ref":"getting-started.html#status"},{"type":"extras","title":"Installation - Getting Started","doc":"In your `mix.exs` file:\n\n```elixir\ndef deps do\n  [\n    {:ex_esdb, \"~> 0.0.8-alpha\"}\n  ]\nend\n```","ref":"getting-started.html#installation"},{"type":"extras","title":"Configuration - Getting Started","doc":"1. in your `config/config.exs` file:\n\n```elixir\nconfig :ex_esdb, :khepri,\n  # the directory where the khepri store will be created\n  data_dir: \"/data\",\n  # the id of the khepri store.\n  store_id: :ex_esdb_store,\n  # the type of database setup to use\n  db_type: :single,\n  # a global timeout in milliseconds\n  timeout: 10_000,\n  # a list of seed nodes to connect to\n  seed_nodes: [],\n  # the name of the pub/sub module to use\n  pub_sub: :ex_esdb_pub_sub\n\n```\n\n2. from the ENVIRONMENT:\n\n```bash\n\nEX_ESDB_DATA_DIR=\"/data\"\nEX_ESDB_STORE_ID=ex_esdb_store\nEX_ESDB_DB_TYPE=single\nEX_ESDB_TIMEOUT=10000\nEX_ESDB_SEED_NODES=\"\"\nEX_ESDB_PUB_SUB=ex_esdb_pub_sub\n\n```","ref":"getting-started.html#configuration"},{"type":"extras","title":"Usage - Getting Started","doc":"```elixir\ndefmodule MyApp.Application do\n  use Application\n\n  @impl true\n  def start(_type, _args) do\n    opts = ExESDB.Options.app_env()\n    children = [\n      {ExESDB.System, opts},\n    ]\n\n    opts = [strategy: :one_for_one, name: MyApp.Supervisor]\n    Supervisor.start_link(children, opts)\n  end\n\nend\n```","ref":"getting-started.html#usage"},{"type":"extras","title":"Testing","doc":"","ref":"testing.html"},{"type":"extras","title":"Read Me","doc":"# ExESDB - A BEAM-native Event Store\n\n`ExESDB` is a BEAM-native Event Store, built on top of the [khepri](https://github.com/rabbitmq/khepri) and [ra](https://github.com/rabbitmq/ra) subsystems.","ref":"readme.html"},{"type":"extras","title":"Motivation - Read Me","doc":"One of the arguments for BEAM development is that it comes \"batteries included\". Be it caching, storage, pub/sub, observability etc... the Erlang ecosystem always has the option to avoid external dependencies.\n\nFor Event Sourcing use cases however, the Event Store is often a separate service.\n\nThis project is an attempt at addressing this point, by building further upon the work of the `rabbitmq/khepri` and `rabbitmq/ra` subsystems.","ref":"readme.html#motivation"},{"type":"extras","title":"Contents - Read Me","doc":"- [Getting Started](system/guides/getting_started.md)","ref":"readme.html#contents"},{"type":"extras","title":"Releases - Read Me","doc":"- [On Hex](https://hex.pm/packages/ex_esdb)\n- [Release Documentation](https://hexdocs.pm/ex_esdb/index.html)","ref":"readme.html#releases"}],"proglang":"elixir","producer":{"name":"ex_doc","version":"0.38.2"},"content_type":"text/markdown"}